@@ -22,6 +22,7 @@ class ConfigData:
         self.devices = {}
         self.scenes = {}
         self.sensors = {}
+        self.binarysensors = {}
         self.covers = {}
         self.roomcontrollers = {}
         self.climatecontrollers = {}
@@ -77,11 +78,11 @@ class ConfigData:
                         self.fieldmap[tv] = {"device": self.sensors[k], "stateName": tk}
 
                 if v["type"] == 'InfoOnlyDigital':
-                    self.sensors[k] = LoxInfoOnlyDigital(k, roomName + v["name"], catName, v["details"], v["type"], v)
+                    self.binarysensors[k] = LoxInfoOnlyDigital(k, roomName + v["name"], catName, v["details"], v["type"], v)
                     _LOGGER.debug("  Map states for InfoOnlyDigital")
                     for tk,tv in v["states"].items():
                         _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
-                        self.fieldmap[tv] = {"device": self.sensors[k], "stateName": tk}
+                        self.fieldmap[tv] = {"device": self.binarysensors[k], "stateName": tk}
 
                 if v["type"] == 'LightControllerV2' and 'subControls' in v:
                     for sk,sv in v["subControls"].items():
